@@ -1,5 +1,5 @@
 package Dist::Build;
-$Dist::Build::VERSION = '0.004';
+$Dist::Build::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -114,7 +114,9 @@ sub Build_PL {
 		}
 	}
 
-	$planner->mkdirs('config', map { catfile('blib', $_) } qw/lib arch bindoc libdoc script bin/);
+	my @blibs = map { catfile('blib', $_) } qw/lib arch bindoc libdoc script bin/;
+	$planner->mkdir($_) for @blibs;
+	$planner->create_phony('config', @blibs);
 	$planner->create_phony('code', 'config', values %most, values %scripts);
 	$planner->create_phony('manify', 'config', values %man1, values %man3);
 	$planner->create_phony('dynamic');
@@ -196,7 +198,7 @@ Dist::Build - A modern module builder, author tools not included!
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
